Orientation for the scrollable direction prop and rule widget.
Maps to iced's horizontal/vertical axis variants.
Summary
Functions
Encodes a direction value to the wire format.
Orientation for the scrollable direction prop and rule widget.
Maps to iced's horizontal/vertical axis variants.
Encodes a direction value to the wire format.