Structural tree hash and golden-file assertions for tests.
Summary
Functions
Asserts that a tree hash matches its golden file.
Builds a tree hash from a renderer tree_hash_response message.
Builds a tree hash from a normalized UI tree.
Computes a SHA-256 hash of the given binary data.
Types
@type t() :: %Plushie.Test.TreeHash{ backend: Plushie.Automation.backend_mode() | nil, hash: String.t(), name: String.t() }
Functions
Asserts that a tree hash matches its golden file.
Builds a tree hash from a renderer tree_hash_response message.
@spec from_tree( name :: String.t(), tree :: map(), backend :: Plushie.Automation.backend_mode() | nil ) :: t()
Builds a tree hash from a normalized UI tree.
Computes a SHA-256 hash of the given binary data.