Empty space -- invisible spacer widget.
Props
width(length) -- space width. Default: shrink. SeePlushie.Type.Length.height(length) -- space height. Default: shrink.a11y(map) -- accessibility overrides. SeePlushie.Type.A11y.
Summary
Functions
Sets accessibility annotations.
Converts this space struct to a ui_node() map via the Plushie.Widget protocol.
Sets the space height.
Creates a new space struct with optional keyword opts.
Sets the space width.
Applies keyword options to an existing space struct.
Types
@type option() :: {:width, Plushie.Type.Length.t()} | {:height, Plushie.Type.Length.t()} | {:a11y, Plushie.Type.A11y.t() | map() | keyword()}
@type t() :: %Plushie.Widget.Space{ a11y: Plushie.Type.A11y.t() | nil, height: Plushie.Type.Length.t() | nil, id: String.t(), width: Plushie.Type.Length.t() | nil }
Functions
@spec a11y(space :: t(), a11y :: Plushie.Type.A11y.t() | map() | keyword()) :: t()
Sets accessibility annotations.
@spec build(space :: t()) :: Plushie.Widget.ui_node()
Converts this space struct to a ui_node() map via the Plushie.Widget protocol.
@spec height(space :: t(), height :: Plushie.Type.Length.t()) :: t()
Sets the space height.
Creates a new space struct with optional keyword opts.
@spec width(space :: t(), width :: Plushie.Type.Length.t()) :: t()
Sets the space width.
Applies keyword options to an existing space struct.